#! /bin/sh

# Change directory to the script directory
cd "$(dirname "$0")"

# Define some vars here
COMPANY_NAME="Hansen Audio"
PRODUCT_NAME="K-Whooms"
LICENSE_FILE="license.txt"
SRCPATH=$(pwd)

# From the VST3 documentation
VST3DIR="$HOME/.vst3"
mkdir -p ${VST3DIR}

# Help will be show when -h|--help
print_help()
{
    echo "USAGE:"
    echo "    ./install_k-whooms [OPTIONS]"
    echo
    echo "FLAGS:"
    echo "    -h, --help       Prints help information"
    echo
    echo "OPTIONS:"
    echo "    -l, --license    Show license information and exit."
    echo "    -u, --uninstall  Call the uninstaller."
    exit
}

# Simply prints the license.txt into the terminal.
print_license()
{
    FILE=${SRCPATH}/${LICENSE_FILE}
    cat "${FILE}"
    exit
}

# Copies files into target directories.
install()
{
    echo "Installing..."
    echo
    SOURCE="${SRCPATH}/${PRODUCT_NAME}.vst3"
    TARGET="${VST3DIR}"
    echo "  Copy ${PRODUCT_NAME}.vst3 to ${TARGET} ... "
    if cp -R ${SOURCE} ${TARGET}
        then echo "  ...done!"
        else echo "  ...failed!"
    fi

    SOURCE="${SRCPATH}/VST3 Presets"
    echo "  Copy ${PRODUCT_NAME} presets to ${TARGET}/VST3 Presets ... "
    if cp -R "${SOURCE}" "${TARGET}/VST3 Presets"
        then echo "  ...done!"
        else echo "  ...failed!"
    fi

    # Only install if apt-get is available e.g. Ubuntu. On Manjaro, no need to install anything.
    if [ -x "$(command -v apk-get)" ];
        then 
        # $ Use 'ldd K-Whooms.so' to list all dependencies.
        echo "  Install system packages ... "
        sudo apt-get install libfreetype6 libx11-xcb1 \
        libfreetype6 \
        libxcb1 \
        libxcb-util1 \
        libxcb-cursor0 \
        libxcb-xkb1 \
        libxkbcommon0 \
        libxkbcommon-x11-0 \
        libcairo2 \
        libfontconfig1 \
        libexpat1 \
        libstdc++6 \
        libsqlite3-0 \
        libxcb-keysyms1
        echo "  ...done!" 
    fi
    
    exit
}

# Deletes folders from where they have been installed by this installer.
uninstall()
{
    DIR="${VST3DIR}/${PRODUCT_NAME}.vst3"
    rm -rf ${DIR}
    exit
}

# Parse script options.
while [ $# -gt 0 ] ;
do
    case "$1" in
        -h|--help)
            print_help
            ;;
        -l|--license)
            print_license
            ;;
        -u|--uninstall)
            uninstall
            ;;
        *) echo "Invalid options passed! Use --help to show valid options." ; exit 1 ;;
    esac
done

# Will be called if no options have been passed.
install